==> mail-1.0.tar.gz: mail-1.0/source/javax/mail/search/ComparisonTerm.java <==
/*
 * ComparisonTerm.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.search;

/**
 * This class models the comparison operator.
 * This is an abstract class; subclasses implement comparisons 
 * for different datatypes.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public abstract class ComparisonTerm
  extends SearchTerm
{

  public static final int LE = 1;
  public static final int LT = 2;
  public static final int EQ = 3;
  public static final int NE = 4;
  public static final int GT = 5;
  public static final int GE = 6;

  /**
   * The comparison.
   */
  protected int comparison;

  /**
   * Equality comparison.
   */
  public boolean equals(Object other)
  {
    return ((other instanceof ComparisonTerm) && 
        ((ComparisonTerm)other).comparison==comparison);
  }

  /**
   * Compute a hashCode for this object.
   */
  public int hashCode()
  {
    return comparison;
  }

}

==> mail-1.1.1.tar.gz: mail-1.1.1/source/javax/mail/search/ComparisonTerm.java <==
/*
 * ComparisonTerm.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.search;

/**
 * A comparison for scalar values.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public abstract class ComparisonTerm
  extends SearchTerm
{

  /**
   * The less than or equal to operator.
   */
  public static final int LE = 1;

  /**
   * The less than operator.
   */
  public static final int LT = 2;

  /**
   * The equality operator.
   */
  public static final int EQ = 3;

  /**
   * The not equal to operator.
   */
  public static final int NE = 4;

  /**
   * The greater than operator.
   */
  public static final int GT = 5;

  /**
   * The greater than or equal to operator.
   */
  public static final int GE = 6;

  /**
   * The comparison operator.
   */
  protected int comparison;

  public boolean equals(Object other)
  {
    return ((other instanceof ComparisonTerm) && 
       ((ComparisonTerm)other).comparison == comparison);
  }

  public int hashCode()
  {
    return comparison;
  }

}
